import React, { useContext, useEffect } from "react"
import '../../App.less'
import { Button, Form, Input } from "antd"
import { LockOutlined, UserOutlined } from "@ant-design/icons"
import Password from "./password"
import phoneLoginImg from '../../assets/image/third-sj.png'
import { userLoginApi } from "../../api"
import { useAjax } from "../../hooks/useAjax"
import SwitchPop from "../../components/switchPop"
import { addAccount } from "../../utils"
import { setToken } from "../../utils/auth"
import { DispatchContext } from "../../App"


/**
 * 账号密码登录
 * @returns 
 */
const LoginPop: React.FC = () => {

    /**************************/
    const { dispatch, state: { initData: { h5LoginLogo: logo } } } = useContext(DispatchContext)!;
    const [form] = Form.useForm()
    const username = Form.useWatch('username', form)

    const userLogin = useAjax((params) => userLoginApi(params))
    /**************************/

    useEffect(() => {
        renderAccountList()
    }, [])

    // 读取缓存中的账号密码
    const renderAccountList = () => {
        let data = localStorage.getItem('acountArrList')
        let storageArr = data ? JSON.parse(data) : []
        let len = storageArr.length - 1
        if (storageArr.length > 0) {
            form.setFieldsValue({ username: storageArr[len].username, password: storageArr[len].password })
        }
    }

    const onFinish = (values: any) => {
        console.log('Success:', values);
        userLogin.run(values).then(res => {
            if (+res.code === 200) {
                addAccount(values.username, values.password)
                dispatch({ type: 'setToken', params: { token: res?.data?.token } })
                setToken(res?.data?.token)
            }
        })
    };

    return <>
        <div className="pop">
            <div className="pop_body">
                <div className="login_head">
                    <img className="login_logo" src={logo} />
                    <span className="login_title">游戏登录</span>
                </div>
                <div className="login_body">
                    <Form
                        name="basic"
                        form={form}
                        onFinish={onFinish}
                    >
                        <Form.Item name="username" style={{ marginBottom: 10 }} rules={[{ required: true, message: '输入登录账号/手机号!' }]}>
                            <Input prefix={<UserOutlined />} placeholder="输入登录账号/手机号" size="large" />
                        </Form.Item>
                        <Form.Item name="password" style={{ marginBottom: 20 }} rules={[{ required: true, message: '输入账号密码!' }]}>
                            <Password prefix={<LockOutlined />} placeholder="输入账号密码" size="large" forgotPassword={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'PWD' } })} />
                        </Form.Item>
                        <Form.Item style={{ marginBottom: 10 }}>
                            <Button type="primary" className="form_button" loading={userLogin.loading} htmlType="submit" size="large">登录</Button>
                        </Form.Item>
                    </Form>
                </div>
                <div className="login_foot">
                    <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_REG' } })}>注册</Button>
                </div>
                <div className="login_third">
                    <a className="login_third-item">
                        <img src={phoneLoginImg} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'PHONE_LOGIN' } })}/>
                    </a>
                </div>
            </div>
        </div>
        {userLogin.loading && <SwitchPop userName={username} />}
    </>
}


export default React.memo(LoginPop)